function [W_TE_n W_TM_n] = SCoeff_Maxwell(L,omega,mu,eps,r,n)




%% make wave numbers for each layer
k = omega*sqrt(mu.*eps);



%% Definitions for spherical bessel function, spherical hankel function and their derivatives


sbesselj = @(n,z) sqrt(pi/2/z)*besselj(n+1/2,z); % spherical bessel
sbesselh = @(n,z) sqrt(pi/2/z)*besselh(n+1/2,1,z); % spherical hankel
Dsbesselj = @(n,z) sbesselj(n-1,z)-(n+1)/z*sbesselj(n,z); % derivative of spherical bessel
Dsbesselh = @(n,z) sbesselh(n-1,z)-(n+1)/z*sbesselh(n,z); % derivative of spherical hankel
Jcal = @(n,z) sbesselj(n,z)+z*Dsbesselj(n,z); % function \mathcal{J}_n
Hcal = @(n,z) sbesselh(n,z)+z*Dsbesselh(n,z); % function \mathcal{H}_n



%% Solving recurrence relations for a0 and b0


taL_over_aL = - sbesselh(n,k(L))/sbesselj(n,k(L));
tbL_over_bL = - Hcal(n,k(L))/Jcal(n,k(L));

vec_a = [taL_over_aL; 1];
vec_b = [tbL_over_bL; 1];

for j=L+1:-1:1+1 % index is translated by 1 (because index 0 is not allowed in MATLAB)
   
    matTE1 = [ sbesselj(n,k(j-1)*r(j)), sbesselh(n,k(j-1)*r(j)) ; 1/mu(j-1)*Jcal(n,k(j-1)*r(j)), 1/mu(j-1)*Hcal(n,k(j-1)*r(j))];
    matTE2 = [ sbesselj(n,k(j)*r(j)), sbesselh(n,k(j)*r(j)) ; 1/mu(j)*Jcal(n,k(j)*r(j)), 1/mu(j)*Hcal(n,k(j)*r(j))];
    
    matTM1 = [ 1/eps(j-1)*Jcal(n,k(j-1)*r(j)), 1/eps(j-1)*Hcal(n,k(j-1)*r(j)) ; sbesselj(n,k(j-1)*r(j)), sbesselh(n,k(j-1)*r(j))];
    matTM2 = [ 1/eps(j)*Jcal(n,k(j)*r(j)), 1/eps(j)*Hcal(n,k(j)*r(j)) ; sbesselj(n,k(j)*r(j)), sbesselh(n,k(j)*r(j)) ];
    

    vec_a = (matTE1)\(matTE2*vec_a);
    vec_b = (matTM1)\(matTM2*vec_b);
end

a0 = vec_a(2)/vec_a(1);
b0 = vec_b(2)/vec_b(1);
W_TE_n = -1i*n*(n+1)/k(0+1)*a0;
W_TM_n = -1i*n*(n+1)/k(0+1)*b0;



