function [W_TE_n W_TM_n] = SCoeff_sphere(omega,muc,epsc,mum,epsm,r,n)




%% make wave numbers 


km = 2*pi*omega/1220;
kc = km*sqrt(muc.*epsc);





%% Definitions for spherical bessel function, spherical hankel function and their derivatives


sbesselj = @(n,z) sqrt(pi/2/z)*besselj(n+1/2,z); % spherical bessel
sbesselh = @(n,z) sqrt(pi/2/z)*besselh(n+1/2,1,z); % spherical hankel
Dsbesselj = @(n,z) sbesselj(n-1,z)-(n+1)/z*sbesselj(n,z); % derivative of spherical bessel
Dsbesselh = @(n,z) sbesselh(n-1,z)-(n+1)/z*sbesselh(n,z); % derivative of spherical hankel
Jcal = @(n,z) sbesselj(n,z)+z*Dsbesselj(n,z); % function \mathcal{J}_n
Hcal = @(n,z) sbesselh(n,z)+z*Dsbesselh(n,z); % function \mathcal{H}_n

WTE1 = muc*sbesselj(n,kc*r)*Jcal(n,km*r)-mum*sbesselj(n,km*r)*Jcal(n,kc*r);
WTE2 = mum*Jcal(n,kc*r)*sbesselh(n,km*r)-muc*sbesselj(n,kc*r)*Hcal(n,km*r);

WTM1 = epsc*sbesselj(n,kc*r)*Jcal(n,km*r)-epsm*sbesselj(n,km*r)*Jcal(n,kc*r);
WTM2 = epsm*Jcal(n,kc*r)*sbesselh(n,km*r)-epsc*sbesselj(n,kc*r)*Hcal(n,km*r);


W_TE_n = -1i*n*(n+1)/km*WTE1/WTE2;
W_TM_n = -1i*n*(n+1)/km*WTM1/WTM2;

